package es.unican.docencia.y2012.eda.practica2;

import java.util.Random;

/**
 * Clase que contiene diversas utilidades para manipular vectores de 
 * enteros, tales como generar un vector de enteros aleatorios de un 
 * determinado tamao 
 * @author Pablo Sanchez (p.sanchez@unican.es)
 *		http://personales.unican.es/sanchezbp	
 */
public class GeneraVectores {
	
	// Inicializamos el generador de numeros aleatorios
	// a un valor cambiante para cada ejecucin
	// NOTA: Esto es una variable global, pero hay una buena razn para 
	// ello. Adems, dicha variable solo se lee y nunca se escribe, lo cual
	// reduce el problema de las variables globales.
	private static Random genera = new Random(System.currentTimeMillis());

	/**
	 * Devuelve un vector del tamanho especificado de enteros 
	 * generados aleatoriamente  
	 * @param tamanho Tamanho del vector a generar
	 * 				  Pre: tamanho > 0 
	 * @return vector de enteros aleatorios
	 */
	public static int [] generaVector(int tamanho) {
		
		// Creamos el array a devolver
		int [] result = new int[tamanho];
		
		// Rellenamos el vector con nmeros aleatorios
		for(int i=0;i<tamanho;i++) {
			result[i] = genera.nextInt();
		} // for
		
		// Devolvemos el vector
		return result;
	} // generaVector
	
	/**
	 * Devuelve verdadero si el vector esta ordenado de forma creciente,
	 * es decir, si para (0<= i,j < vector.length), si i < j, v[i] <= v[j], devuelve 
	 * falso el otro caso.  
	 * @param vector Vector a comprobar si esta ordernado
	 * 				 Pre: (vector != null) and (vector.length > 0)
	 * @return true si el vector esta ordenado de forma creciente, false en otro caso
	 */
	public boolean estaOrdenado(int []vector) {
		
		int i = 0;
		
		while ((i < (vector.length-1)) && (vector[i] <= vector[i+1])) {
			i = i + 1;
		} // while
		
		return (i == (vector.length-1));
	} // estaOrdenado
	
	/**
	 * Devuelve un vector del tamanho indicado y que ademas esta ordenado 
	 * @param tamanho El tamanho del vector a generar
	 * @return Un vector de enteros ordenados de menor a mayor y del tamanho especificado 
	 */
	public static int [] generaVectorOrdenado(int tamanho) {
		
		int [] result = new int[tamanho];
		
		for(int i=0;i< tamanho;i++) {
			result[i] = i;
		} // for
		
		return result; 
	} // generaVectorOrdenado
	
	/**
	 * Genera un valor entero aleatorio dentro del rango [inicioRango, finRango]
	 * Precondition: 0 <= inicioRango <= finRango 
	 * @param inicioRango Menor entero aleatorio a ser generado
	 * @param finRango Mayor entero aleatorio a ser generado
	 * @return  El valor del entero aleorio generado dentro del rango especificado
	 *
	 */
	public static int generaEnteroAleatorio(int inicioRango, int finRango) {
		return genera.nextInt(finRango - inicioRango + 1) + inicioRango;
	} // generaEnteroAleatorio  
	
} // GeneraVectores
